<?php

/**
 * This file is part of ILIAS, a powerful learning management system
 * published by ILIAS open source e-Learning e.V.
 *
 * ILIAS is licensed with the GPL-3.0,
 * see https://www.gnu.org/licenses/gpl-3.0.en.html
 * You should have received a copy of said license along with the
 * source code, too.
 *
 * If this is not the case or you just want to try ILIAS, you'll find
 * us at:
 * https://www.ilias.de
 * https://github.com/ILIAS-eLearning
 *
 *********************************************************************/

declare(strict_types=1);

namespace ILIAS\Plugin\PlagScanExercise\PlagScan;

use InvalidArgumentException;

class AssignmentConfigData
{
    protected array $valid_start_check_values = ['manual','automatic','immediate'];
    protected array $valid_share_setting_values = ['never','deadline', 'always'];
    protected array $valid_share_type_values = ['percentage_only', 'percentage_link'];
    protected int $exercise_obj_id;
    protected int $assignment_id;

    protected bool $activation;
    protected string $start_check;
    protected string $share_setting;
    protected string $share_type;

    public function __construct(
        int $exercise_obj_id,
        int $assignment_id,
        bool $activation,
        string $start_check,
        string $share_setting,
        string $share_type
    ) {
        $this->exercise_obj_id = $exercise_obj_id;
        $this->assignment_id = $assignment_id;

        $this->activation = $activation;
        if ($this->activation) {
            if (in_array($start_check, $this->valid_start_check_values, true)) {
                $this->start_check = $start_check;
            } else {
                throw new InvalidArgumentException('Not a valid start_check: ' . $start_check);
            }

            if (in_array($share_setting, $this->valid_share_setting_values, true)) {
                $this->share_setting = $share_setting;
            } else {
                throw new InvalidArgumentException('Not a valid share_setting: ' . $share_setting);
            }

            if (in_array($share_type, $this->valid_share_type_values, true)) {
                $this->share_type = $share_type;
            } else {
                throw new InvalidArgumentException('Not a valid share_type: ' . $share_type);
            }
        } else {
            $this->start_check = 'none';
            $this->share_setting = 'none';
            $this->share_type = 'none';
        }
    }

    public function getExerciseObjId(): int
    {
        return $this->exercise_obj_id;
    }

    public function getAssignmentId(): int
    {
        return $this->assignment_id;
    }

    public function getActivation(): bool
    {
        return $this->activation;
    }

    public function getStartCheck(): string
    {
        return $this->start_check;
    }

    public function getShareSetting(): string
    {
        return $this->share_setting;
    }

    public function getShareType(): string
    {
        return $this->share_type;
    }
}
