<?php

/**
 * This file is part of ILIAS, a powerful learning management system
 * published by ILIAS open source e-Learning e.V.
 *
 * ILIAS is licensed with the GPL-3.0,
 * see https://www.gnu.org/licenses/gpl-3.0.en.html
 * You should have received a copy of said license along with the
 * source code, too.
 *
 * If this is not the case or you just want to try ILIAS, you'll find
 * us at:
 * https://www.ilias.de
 * https://github.com/ILIAS-eLearning
 *
 *********************************************************************/

declare(strict_types=1);

namespace PlagScan\Helper;

use ilSetting;
use PlagScan\API;

class Base
{
    protected API $handler;
    protected string $access_token;

    public function __construct(string $host, string $version = 'v3')
    {
        $this->handler = API::getInstance($host, $version);
        $this->createAccessToken();
    }

    /**
     * @return array|string
     */
    public function ping()
    {
        return $this->handler->request('ping', 'GET');
    }

    /**
     * @return array|string
     */
    public function checkCallbackConfiguration()
    {
        return $this->handler->request('checkcallback', 'PUT', $this->access_token);
    }

    /**
     * @return array|string
     */
    public function createAccessToken(string $client_id = '', string $client_secret = '')
    {
        $settings = new ilSetting('psx');
        if ($client_id === '') {
            $client_id = $settings->get('psx_clientid', '');
        }
        if ($client_secret === '') {
            $client_secret = $settings->get('psx_apikey', '');
        }

        $response = $this->handler->request(
            'token',
            'POST',
            '',
            [
                'client_id' => $client_id,
                'client_secret' => $client_secret
            ]
        );

        if (isset($response['access_token'])) {
            $this->access_token = $response['access_token'];
        }

        return $response;
    }
}
